Blahblalala (@blahlaja) | nitter
Description: Retail Investor, #Shiba General, #Shiba Influencer, #Shib Defense Breed, #Bone , #Leash influencer, #PawSwap influencer, #DogPad Influencer, #SHIBARMYUNITED.

Blahblalala @blahlaja

Retail Investor, #Shiba General, #Shiba Influencer, #Shib Defense Breed, #Bone , #Leash influencer, #PawSwap influencer, #DogPad Influencer, #SHIBARMYUNITED.

U.S.A.
facebook.com/groups/61147733…
Joined May 2021

- Tweets 5,654
- Following 869
- Followers 416
- Likes 5,572

792 Photos and videos
792 Photos and videos

- Tweets
- Tweets & Replies
- Media
- Search

Pinned Tweet
Blahblalala @blahlaja
Feb 16
WOOOOOOOOOOOOF!!! #SHIB #SHIB #SHIB @BoneShiba @ShibariumNet @ShibaInuHodler @Shibtoken @ShytoshiKusama @shibainuart @LucieSHIB @RyoshiResearch
1
8

## No items found